@@ -1,7 +1,7 @@
 /*
  * melonDS - Jolly Good API Port
  *
- * Copyright (C) 2022-2025 Rupert Carmichael
+ * Copyright (C) 2022-2026 Rupert Carmichael
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,14 +33,11 @@
 #include "jg_nds_mds.h"
 #endif
 
-#include <samplerate.h>
-
 #include "NDS.h"
 
 #include "version.h"
 
 #define SAMPLERATE 48000
-#define SAMPLERATE_IN 32823.6328125
 #define FRAMERATE 60
 #define CHANNELS 2
 #define NUMINPUTS 3
@@ -78,7 +75,7 @@ static jg_videoinfo_t vidinfo = {
 };
 
 static jg_audioinfo_t audinfo = {
-    JG_SAMPFMT_FLT32,
+    JG_SAMPFMT_INT16,
     SAMPLERATE,
     CHANNELS,
     (SAMPLERATE / FRAMERATE) * CHANNELS,
@@ -128,12 +125,6 @@ enum {
     EXTERNAL_FIRMWARE
 };
 
-// Resampling
-static SRC_STATE *srcstate = nullptr;
-static SRC_DATA srcdata;
-static int16_t inbuf[((SAMPLERATE / FRAMERATE) * CHANNELS) << 1];
-static float inbuf_f[((SAMPLERATE / FRAMERATE) * CHANNELS) << 1];
-
 // Screen Layout
 static void (*mds_video_render)(void);
 static unsigned mainscr = 0;
@@ -462,27 +453,37 @@ void Addon_RumbleStart(u32, void*) {
 void Addon_RumbleStop(void*) {
 }
 
+int Mic_ReadInput(short*, int, void*) {
+    return 0;
+}
+
+void Mic_Start(void*) {
+}
+
+void Mic_Stop(void*) {
+}
+
+AACDecoder* AAC_Init() {
+    return nullptr;
+}
+
+void AAC_DeInit(AACDecoder*) {
+}
+
+bool AAC_Configure(AACDecoder*, int, int) {
+    return false;
+}
+
+bool AAC_DecodeFrame(AACDecoder*, void const*, int, void*, int) {
+    return false;
+}
+
 void Log(LogLevel level, const char* fmt, ...) {
     jg_cb_log(level, fmt);
 }
 
 } // namespace Platform
 
-// Audio Helpers
-static void mds_audio_push(void) {
-    u32 insamps = nds->SPU.GetOutputSize();
-    nds->SPU.ReadOutput(inbuf, insamps);
-
-    src_short_to_float_array(inbuf, inbuf_f, insamps << 1);
-    srcdata.data_in = inbuf_f;
-    srcdata.data_out = (float*)audinfo.buf;
-    srcdata.input_frames = insamps;
-    srcdata.output_frames = audinfo.spf;
-    src_process(srcstate, &srcdata);
-
-    jg_cb_audio(srcdata.output_frames_gen << 1);
-}
-
 // Video Helpers
 static void mds_video_render_vertical(void) {
     size_t scrsz = SCREEN_W * SCREEN_H; // Single screen size
@@ -747,10 +748,6 @@ void jg_deinit(void) {
     delete nds;
     nds = nullptr;
     NDS::Current = nds;
-
-    if (srcstate)
-        srcstate = src_delete(srcstate);
-    srcstate = nullptr;
 }
 
 void jg_reset(int) {
@@ -760,10 +757,16 @@ void jg_reset(int) {
 }
 
 void jg_exec_frame(void) {
-    // Refresh input, run a frame, push audio to resampler, render video
+    // Refresh input, run a frame
     mds_input_refresh();
     nds->RunFrame();
-    mds_audio_push();
+
+    // Output accumulated audio samples
+    u32 samps = nds->SPU.GetOutputSize();
+    nds->SPU.ReadOutput((int16_t*)audinfo.buf, samps);
+    jg_cb_audio(samps << 1);
+
+    // Render the video frame
     mds_video_render();
 }
 
@@ -922,14 +925,6 @@ void jg_setup_video(void) {
 }
 
 void jg_setup_audio(void) {
-    if (srcstate == nullptr) {
-        int err;
-        srcstate = src_new(SRC_SINC_FASTEST, CHANNELS, &err);
-        memset(&srcdata, 0, sizeof(SRC_DATA)); // MUST be zero initialized
-    }
-
-    src_reset(srcstate);
-    srcdata.src_ratio = SAMPLERATE / SAMPLERATE_IN;
 }
 
 void jg_set_inputstate(jg_inputstate_t *ptr, int port) {
