@@ -27,14 +27,34 @@
 
 #include "ARCodeFile.h"
 
-Q_DECLARE_METATYPE(melonDS::ARCodeList::iterator)
-Q_DECLARE_METATYPE(melonDS::ARCodeCatList::iterator)
-
 namespace Ui { class CheatsDialog; }
 class CheatsDialog;
+class CheatImportDialog;
 
 class EmuInstance;
 
+namespace melonDS
+{
+    class ARDatabaseDAT;
+}
+
+class CheatListModel : public QStandardItemModel
+{
+    Q_OBJECT
+
+public:
+    CheatListModel(QObject* parent = nullptr) : QStandardItemModel(parent) {}
+
+    void populateCheatListCat(QStandardItem* parentitem, melonDS::ARCodeCat& parentcat);
+
+    Qt::DropActions supportedDragActions() const override { return Qt::MoveAction; }
+    Qt::DropActions supportedDropActions() const override { return Qt::MoveAction; }
+
+    QMimeData* mimeData(const QModelIndexList& indexes) const override;
+    bool canDropMimeData(const QMimeData* mime, Qt::DropAction action, int row, int column, const QModelIndex& parent) const override;
+    bool dropMimeData(const QMimeData* mime, Qt::DropAction action, int row, int column, const QModelIndex& parent) override;
+};
+
 class ARCodeChecker : public QSyntaxHighlighter
 {
     Q_OBJECT
@@ -74,25 +94,40 @@ public:
     }
 
 private slots:
-    void on_CheatsDialog_accepted();
-    void on_CheatsDialog_rejected();
+    void done(int r) override;
 
     void on_btnNewCat_clicked();
     void on_btnNewARCode_clicked();
     void on_btnDeleteCode_clicked();
+    void on_btnImportCheats_clicked();
+    void onImportCheatsFinished(int res);
 
     void onCheatSelectionChanged(const QItemSelection& sel, const QItemSelection& desel);
     void onCheatEntryModified(QStandardItem* item);
 
-    void on_txtCode_textChanged();
+    void on_btnEditCode_clicked();
+    void on_btnSaveCode_clicked();
+    void on_btnCancelEdit_clicked();
 
 private:
     Ui::CheatsDialog* ui;
 
     EmuInstance* emuInstance;
 
+    melonDS::u32 gameCode;
+    melonDS::u32 gameChecksum;
+
     melonDS::ARCodeFile* codeFile;
     ARCodeChecker* codeChecker;
+
+    melonDS::ARDatabaseDAT* importDB;
+    CheatImportDialog* importDlg;
+
+    bool updatingEnableChk;
+
+    void populateCheatList();
+    void populateCheatInfo();
+    std::vector<melonDS::u32> convertCodeInput();
 };
 
 #endif // CHEATSDIALOG_H
